@@ -18,7 +18,7 @@ Test::Run::CmdLine - Analyze tests from the command line using Test::Run
 
 use vars (qw($VERSION));
 
-$VERSION = '0.0100_04';
+$VERSION = '0.0101';
 
 use vars (qw(@ISA));
 
@@ -304,7 +304,7 @@ sub add_to_backend_plugins
     unshift @{$self->backend_plugins()}, $plugin;
 }
 
-=head1 AUTHOR
+=head1 AUTHORS
 
 Shlomi Fish, C<< <shlomif@iglu.org.il> >>
 
@@ -316,6 +316,41 @@ L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Test-Run-CmdLine>.
 I will be notified, and then you'll automatically be notified of progress on
 your bug as I make changes.
 
+=head1 SUPPORT
+
+You can find documentation for this module with the perldoc command.
+
+    perldoc Test::Run::CmdLine
+
+You can also look for information at:
+
+=over 4
+
+=item * AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/Test::Run::CmdLine>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/d/Test::Run::CmdLine>
+
+=item * RT: CPAN's request tracker
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Test::Run::CmdLine>
+
+=item * Search CPAN
+
+L<http://search.cpan.org/dist/Test::Run::CmdLine/>
+
+=back
+
+=head1 SOURCE AVAILABILITY
+
+The latest source of Test::Run::CmdLine is available from the Test::Run
+BerliOS Subversion repository:
+
+L<https://svn.berlios.de/svnroot/repos/web-cpan/Test-Harness-NG/>
+
 =head1 ACKNOWLEDGEMENTS
 
 =head1 COPYRIGHT & LICENSE
